# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# written by: Jeff Ortel ( jortel@redhat.com )

import sys
sys.path.append('../')

import logging
import traceback as tb
from tests import *
from suds import WebFault
from suds.client import Client

errors = 0

setup_logging()

#logging.getLogger('suds.client').setLevel(logging.DEBUG)
#logging.getLogger('suds.xsd.schema').setLevel(logging.DEBUG)

from suds.xsd.sxbasic import Import
Import.bind('http://schemas.xmlsoap.org/soap/encoding/')

def start(url):
    print '\n________________________________________________________________\n' 
    print 'Test @ ( %s )' % url

def timButler():
    global errors
    try:
        url = 'file:///home/jortel/Desktop/suds/TimButler/rep3.xml'
        start(url)
        client = Client(url)
        print client
        key = client.factory.create('ns2:TestKey')
        key.testId = 'xx'
        print key
        print client.service.retrieve('hello', key)
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()
        
def ticket39():
    global errors
    try:
        url = 'file:///home/jortel/Desktop/suds/Ticket39/wsdl.xml'
        start(url)
        client = Client(url)
        print client
        c = client.factory.create('ns0:CompositeType')
        print c
        c.BoolValue = True
        c.StringValue = 'hello'
        print client.service.GetDataUsingDataContract(c)
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()
        
def scrumworks():
    from datetime import datetime
    global errors    
    try:
        url = 'file:///home/jortel/Desktop/suds/scrumworks.xml'
        start(url)
        client = Client(url)
        print client
        product = client.factory.create('ns0:ProductWSO')
        product.businessWeightUnits = None
        effortUnits = "Story points"
        product.id = -139070673735326720
        product.keyPrefix = "API"
        product.name = "API Test"
        product.programId = None
        product.trackTimeSpent = False
        client.service.getReleases(product)
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()
        
def sourceforge():
    global errors
    reply = open('/home/jortel/Desktop/reply.xml').read()
    try:
        url = 'file:///home/jortel/Desktop/suds/sourceforge.TrackerApp.xml'
        start(url)
        client = Client(url)
        print client
        data = client.service.getArtifactData('', '', inject=dict(reply=reply))
        print data
        data.flexFields.values.values[1] = 8
        client.service.setArtifactData('', data, "Updates from ScrumWorks Pro")
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()
        
def johnpope():
    from datetime import datetime
    global errors    
    try:
        url = 'http://sipixdev1.neustarlab.biz:8080/sip_ix/SendBatchRequest?wsdl'
        start(url)
        client = Client(url)
        print client
        reqType = client.factory.create('ns1:RequestType.QueryTN')
        print '\n\nclient create of RequestType.QueryTN:\n'
        print reqType.QueryTN
        reqType.QueryTN.TransactionID = 1209553743270
        reqType.QueryTN.TN = '5714341000'
        reqType.QueryTN.Tier = '2'
        reqType.QueryTN.DNSProfileID = 'JP_5714345560'
        print '\n\nreqType.QueryTN is now:\n'
        print reqType.QueryTN
        result = client.service.SendBatchRequest(reqType.QueryTN)
        print '\n\After SendRequest, result = \n'
        print result
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()

def misc():
    global errors
    try:
        #url = 'file:///home/jortel/Desktop/jahSoapService.xml'
        #url = 'https://vsptest.i-911.net/I911Impl/i911ws?WSDL'
        #url = 'file:///home/jortel/Desktop/vsptest.i-911.net.wsdl'
        #url = 'http://beanstream.com/soap/ProcessTransaction.wsdl'
        #url = 'file:///home/jortel/Desktop/suds/Ticket39/wsdl.xml'
        #url = 'file:///home/jortel/Desktop/suds/rep3.xml'
        #url = 'file:///home/jortel/svn/suds/trunk/tests/test.wsdl'
        #url = 'http://webservices.amazon.com/AWSECommerceService/AWSECommerceService.wsdl'
        #url = 'http://www.ncbi.nlm.nih.gov/entrez/eutils/soap/eutils.wsdl'
        #url = 'https://212.1.248.243:55567/webdialer/services/WebdialerSoapService?wsdl'
        url = 'http://localhost:8080/externaldataservicemodule/CtsDataExportService?wsdl'
        url = 'http://mssoapinterop.org/asmx/simple.asmx?WSDL'
        start(url)
        client = Client(url)
        print client
        print client.service.echoInteger(42)
    except WebFault, f:
        errors += 1
        print f
        print f.fault
    except Exception, e:
        errors += 1
        print e
        tb.print_exc()

if __name__ == '__main__':
    #johnpope() # ticket 49
    #sourceforge()
    #scrumworks()
    #timButler()
    #ticket39()
    misc()
    print '\nFinished: errors = %d' % errors

